



if not exist %LIBRARY_PREFIX%\bin\lfortran.exe exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
lfortran --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
lfortran --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
jupyter kernelspec list --json
IF %ERRORLEVEL% NEQ 0 exit /B 1
jupyter kernelspec remove -f fortran
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
